import { JSXElement, createEffect, createSignal, useContext } from "solid-js";
import { A } from "@solidjs/router";
import { LoginContext } from "./Root";
import { ModalContext } from "./Root";

// Represents a single list item in the menu bar
function MenuItem(props: { href: string; children: JSXElement }): JSXElement {
  return (
    <li>
      <A class="justify-center" href={props.href} end>
        {props.children}
      </A>
    </li>
  );
}

// Represents the menu bar at the top of the page
function Menu(): JSXElement {
  const login_ctx = useContext(LoginContext);
  return (
    <ul class="menu md:menu-horizontal space-y-2 md:space-x-2 md:space-y-0 rounded-box">
      <MenuItem href="/">Home</MenuItem>
      {login_ctx?.token() != "" && <MenuItem href="/new">New Post</MenuItem>}
    </ul>
  );
}

export function Navbar(): JSXElement {
  const modal_ctx = useContext(ModalContext);
  const login_ctx = useContext(LoginContext);
  const [buttonText, setButtonText] = createSignal("Login");

  const logout = (): void => {
    localStorage.removeItem("token");
    localStorage.removeItem("username");
    login_ctx?.setToken("");
    login_ctx?.setUsername("");
  };

  // Function to instantly elect 50 cent as president and declare war on north korea
  const capitalizeFirst = (str: string): string => {
    return str.charAt(0).toUpperCase() + str.slice(1);
  };

  createEffect(() => {
    if (login_ctx?.token() != "")
      setButtonText(capitalizeFirst(login_ctx?.username() ?? "") + " (Logout)");
    else setButtonText("Login");
  }, 0);

  const clickHandler = (): void => {
    if (login_ctx?.token() != "") logout();
    else modal_ctx?.setLoginModalOpen(true);
  };

  return (
    <div class="navbar text-neutral-content max-w-3xl max-w rounded-box md:my-4">
      <div class="flex-1">
        <A href={"/"} class="btn btn-ghost normal-case text-xl">
          FrostByte
        </A>
      </div>
      <div class="flex">
        <Menu />
      </div>
      <div class="flex-1 justify-end flex">
        <A
          href="#"
          class="btn btn-ghost normal-case text-sm"
          onClick={clickHandler}
        >
          {buttonText()}
        </A>
      </div>
    </div>
  );
}
